
What IS goulash?
----------------

It's sort of like soup, but more viscous, and as for what is actually inside
the truth is that no one really knows.  Likewise for this library.  Random odds
and ends, common tools and patterns shared by my other projects.


 Working with goulash
---------------------

Downloading:

 $ git clone https://github.com/mattvonrocketstein/goulash.git

Running tests:

 $ cd goulash
 $ virtualenv goulash_test
 $ source goulash_test/bin/activate
 $ pip install tox
 $ tox
